/**
 * \file
 *
 * \brief Board-specific definitions for ATSTk1002
 *
 * \author Atmel AVR32 Support \<avr32\@atmel.com\>
 *
 * Copyright (C) 2010 Atmel Corporation. All rights reserved.
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 * Atmel AVR product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#ifndef BOARD_H_INCLUDED
#define BOARD_H_INCLUDED

#include <sys/mount.h>
#include "filesystem.h"

#define BOARD_IMAGE_DIR		"atstk1002-upgrade"
#define BOARD_BOOTLOADER_DEVICE	"mtd:u-boot"
#define BOARD_ENV_DEVICE	"mtd:env"
#define BOARD_MTD_BOOTARGS	"root=mtd:root rootfstype=jffs2"
#define BOARD_UPGRADE_MTDPARTS						\
	"physmap-flash.0:0x20000(u-boot),0x7d0000(root),0x10000(env)"
#define BOARD_UIMAGE_PATH	"/boot/uImage"

static const char *const board_env_preserve[] = {
	"ethaddr",
	"eth1addr",
};

static inline int board_mount_filesystems(const char *mountpoint)
{
	int ret;

	ret = fs_init_jffs2("mtd:root", mountpoint);

	return ret;
}

static inline void board_unmount_filesystems(const char *mountpoint)
{
	if (umount(mountpoint) < 0) {
		fprintf(stderr, "Failed to unmount %s: %s\n",
				mountpoint, strerror(errno));
	}
}

#endif /* BOARD_H_INCLUDED */
