/**
 * \file
 *
 * \brief Common filesystem-related functionality
 *
 * \author Atmel AVR32 Support \<avr32\@atmel.com\>
 *
 * Copyright (C) 2010 Atmel Corporation. All rights reserved.
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 * Atmel AVR product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#include <errno.h>
#include <stdio.h>
#include <string.h>
#include <sys/mount.h>

#include "util.h"

int fs_mount(const char *dev, const char *mountpoint, const char *fstype)
{
	int err;

	fprintf(stderr, "Mounting %s on %s: ", dev, mountpoint);

	if (mkdir_p(mountpoint, 0777)) {
		err = errno;
		fprintf(stderr, "FAILED\n");
		fprintf(stderr, "Failed to create directory %s: %s\n",
				mountpoint, strerror(err));
		goto fail;
	}
	if (mount(dev, mountpoint, fstype, 0, NULL)) {
		err = errno;
		fprintf(stderr, "FAILED\n");
		fprintf(stderr, "Failed to mount %s on %s: %s\n",
				dev, mountpoint, strerror(err));
		goto fail;
	}

	fprintf(stderr, "OK\n");

	return 0;

fail:
	return -1;
}
