/**
 * \file
 *
 * \brief Unsorted Block Image File System
 *
 * \author Atmel AVR32 Support \<avr32\@atmel.com\>
 *
 * Copyright (C) 2010 Atmel Corporation. All rights reserved.
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 * Atmel AVR product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#include <errno.h>
#include <stdarg.h>
#include <stdio.h>
#include <string.h>

#include "libmtd/mtd.h"
#include "filesystem.h"
#include "subprocess.h"

int fs_init_ubifs(const char *dev, unsigned int ubi_devno,
		const char *vol_name, const char *mountpoint)
{
	char		mtd_devname[64] = "/dev/";
	char		ubi_devname[64];
	char		ubi_volname[64];

	if (mtd_get_devname(mtd_devname + 5,
				sizeof(mtd_devname) - 5, dev) < 0) {
		fprintf(stderr, "Could not find MTD device %s: %s\n",
				dev, strerror(errno));
		return -1;
	}

	snprintf(ubi_devname, sizeof(ubi_devname), "/dev/ubi%u", ubi_devno);

	if (run_helper("/usr/sbin/ubiformat", mtd_devname, "--yes", NULL) < 0)
		return -1;
	if (run_helper("/usr/sbin/ubiattach", "/dev/ubi_ctrl",
				"-m", mtd_devname + 8, NULL) < 0)
		return -1;
	if (run_helper("/usr/sbin/ubimkvol", ubi_devname,
				"-m", "-N", vol_name, NULL) < 0)
		return -1;

	snprintf(ubi_volname, sizeof(ubi_volname), "ubi%u:%s",
			ubi_devno, vol_name);

	return fs_mount(ubi_volname, mountpoint, "ubifs");
}
