/**
 * \file
 *
 * \brief Locating a sector
 *
 * \author Atmel AVR32 Support \<avr32\@atmel.com\>
 *
 * Copyright (C) 2008-2010 Atmel Corporation. All rights reserved.
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 * Atmel AVR product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#include <mtd/mtd-user.h>

#include "mtd.h"
#include "mtd_internal.h"

/**
 * Find a flash sector which covers a given offset.
 *
 * @param[in] mtd MTD device.
 * @param[in] offset Offset into the MTD device.
 * @param[out] sector Sector covering @a offset.
 *
 * @retval 0 A sector was found, and @a sector was initialized with
 * its offset and length.
 * @retval -1 No sector covering @a offset was found, and errno was
 * set to ENXIO.
 */
int __export mtd_find_sector(const struct mtd *mtd, mtd_off_t offset,
		struct mtd_sector *sector)
{
	struct region_info_user *region;
	unsigned int		index;

	region = _mtd_find_region(mtd, offset);
	if (!region)
		return -1;

	index = (offset - region->offset) / region->erasesize;
	sector->offset = region->offset + index * region->erasesize;
	sector->len = region->erasesize;
	sector->mtd_priv = region;

	return 0;
}
