/**
 * \file
 *
 * \brief Internal definitions for the MTD library.
 *
 * \author Atmel AVR32 Support \<avr32\@atmel.com\>
 *
 * Copyright (C) 2008-2010 Atmel Corporation. All rights reserved.
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 * Atmel AVR product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#ifndef LIBMTD_INTERNAL_H_INCLUDED
#define LIBMTD_INTERNAL_H_INCLUDED

#include "mtd.h"

#include <mtd/mtd-user.h>
#include <stdbool.h>

enum mtd_volume_type {
	MTD_VOLUME_UNKNOWN,
	MTD_VOLUME_JFFS2,
};

struct mtd {
	int				fd;
	struct mtd_info_user		info;
	int				sector_count;
	int				region_count;
	struct region_info_user		*region;
	bool				check_bad_blocks;
	enum mtd_volume_type		volume_type;
	void				*volume_data;
};

#define __export	__attribute__((visibility("default")))

#define min(x, y) ({							\
	__typeof__(x) __x = (x);					\
	__typeof__(y) __y = (y);					\
	__x < __y ? __x : __y;						\
})
#define max(x, y) ({							\
	__typeof__(x) __x = (x);					\
	__typeof__(y) __y = (y);					\
	__x > __y ? __x : __y;						\
})

int _mtd_name_to_index(const char *mtd_name);
struct region_info_user *_mtd_find_region(const struct mtd *mtd,
		mtd_off_t offset);

#endif /* LIBMTD_INTERNAL_H_INCLUDED */
