/**
 * \file
 *
 * \brief Upgrade utility core functionality
 *
 * \author Atmel AVR32 Support \<avr32\@atmel.com\>
 *
 * Copyright (C) 2008-2010 Atmel Corporation. All rights reserved.
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 * Atmel AVR product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#ifndef UPGRADE_H_INCLUDED
#define UPGRADE_H_INCLUDED

#include <signal.h>
#include <stdbool.h>
#include <sys/stat.h>
#include <sys/types.h>

struct environment;
struct mtd;

int upgrade_bootloader(const char *dev, const char *img);

int unpack_filesystem(const char *rootpath, const char *image);

struct environment *env_create(size_t size, bool redundant);
void env_destroy(struct environment *env);

const char *env_get(struct environment *env, const char *name);
int env_set(struct environment *env, const char *name, const char *value);
void env_refresh(struct environment *env);

int env_read_from_mtd(struct environment *env, struct mtd *main_mtd,
		struct mtd *backup_mtd);
int env_write_to_mtd(struct environment *env, struct mtd *mtd);
int env_write_to_file(struct environment *env, int fd);

#endif /* UPGRADE_H_INCLUDED */
