/**
 * \file
 *
 * \brief Misc utility functions
 *
 * \author Atmel AVR32 Support \<avr32\@atmel.com\>
 *
 * Copyright (C) 2008-2010 Atmel Corporation. All rights reserved.
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 * Atmel AVR product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#ifndef UTIL_H_INCLUDED
#define UTIL_H_INCLUDED

#include <stdbool.h>
#include <sys/types.h>
#include <unistd.h>

#define ARRAY_LEN(x)	(sizeof(x) / sizeof((x)[0]))

#ifdef __avr32__
#define min(x, y) ({							\
	__typeof__(x) __ret;						\
	__asm__("min %0, %1, %2" : "=r"(__ret) : "r"(x), "r"(y));	\
	__ret;								\
})
#define max(x, y) ({							\
	__typeof__(x) __ret;						\
	__asm__("max %0, %1, %2" : "=r"(__ret) : "r"(x), "r"(y));	\
	__ret:								\
})
#else
#define min(x, y) ({							\
	__typeof__(x) __x = (x);					\
	__typeof__(y) __y = (y);					\
	__x < __y ? __x : __y;						\
})
#define max(x, y) ({							\
	__typeof__(x) __x = (x);					\
	__typeof__(y) __y = (y);					\
	__x > __y ? __x : __y;						\
})
#endif

ssize_t read_all(int fd, void *buf, size_t count);
int mkdir_p(const char *path, mode_t mode);
bool file_exists(const char *path);
int copy_file(const char *src_path, const char *dst_path);

#endif /* UTIL_H_INCLUDED */
